@@ -1,5 +1,7 @@
 from pychart import *
 import chartdemo
+
+theme.getopt()
 orgdata = chart_data.read_csv("lines.csv")
 data=[]
 
@@ -12,6 +14,7 @@ ar = area.T(x_axis=axis.X(label="X", format="/a-30{}%d", tic_interval=20),
 
 ar.add_plot(line_plot.T(data=data, tick_mark=tick_mark.blackcircle1,
 			error_bar = error_bar.bar4, 
-			y_min_col=2, q_min_col=3, line_style=None))
+			y_error_minus_col=2, y_qerror_minus_col=3,
+                        line_style=None))
 ar.draw()
 
