@@ -1,5 +1,5 @@
 from pychart import *
-import Docsupport
+import pychart.doc_support
 import chartdemo
 import re
 
@@ -8,8 +8,7 @@ y = 500
 
 def draw_rect(color):
     global x, y
-    name = Docsupport.stringify_value(color)
-    pychart_util.warn("COLOR=", name, ">", color.r, ">", color.g, ">", color.b, "\n")
+    name = pychart.doc_support.stringify_value(color)
     name = re.sub("color\\.", "", name)
     fill = fill_style.Plain(bgcolor = color)
     canvas.rectangle(line_style.default, fill, x, y, x+15, y+15)
@@ -18,7 +17,8 @@ def draw_rect(color):
     tb.draw()
 
 for style in color.standards.list():
-    if style.r == style.g and style.g == style.b:
+    if (not theme.use_color and style.r == style.g and style.g == style.b) or \
+       theme.use_color:
         draw_rect(style)
         if x >= chartdemo.MaxWidth:
             x=100
