@@ -1,5 +1,5 @@
 from pychart import *
-import Docsupport
+import pychart.doc_support
 import re
 
 x = 100
@@ -12,7 +12,7 @@ m=60
 
 def drawerror_bar(e):
     global x, y
-    name = Docsupport.stringify_value(e)
+    name = pychart.doc_support.stringify_value(e)
     name = re.sub("error_bar\\.", "", name)
     tb = text_box.T(text="/hC" + name, loc=(x, y-m-20), line_style=None)
     tb.draw()
@@ -29,10 +29,10 @@ drawerror_bar(error_bar.bar5)
 
 xmax = x+20-50
 
-canvas.line(line_style.gray7dash1, xmin-20, y, xmax, y)
+canvas.line(line_style.gray70_dash1, xmin-20, y, xmax, y)
 
-canvas.line(line_style.gray7dash1, xmin-20, y-q, xmax, y-q)
-canvas.line(line_style.gray7dash1, xmin-20, y+q, xmax, y+q)
+canvas.line(line_style.gray70_dash1, xmin-20, y-q, xmax, y-q)
+canvas.line(line_style.gray70_dash1, xmin-20, y+q, xmax, y+q)
 tb = text_box.T(text="quartile", loc=(xmax+40, y), line_style=None)
 tb.add_arrow(tipLoc=(xmax+55, y+q)) #, tail='tc')
 tb.add_arrow(tipLoc=(xmax+55, y-q)) #, tail='bc')
