@@ -1,5 +1,5 @@
 from pychart import *
-import Docsupport
+import pychart.doc_support
 import chartdemo
 import re
 
@@ -8,7 +8,8 @@ y = 500
 
 def drawRect(fill):
     global x, y
-    name = Docsupport.stringify_value(style)
+    name = pychart.doc_support.stringify_value(style)
+    #print "name=", name
     name = re.sub("fill_style\\.", "", name)
     canvas.rectangle(line_style.default, fill, x, y, x+15, y+15)
     tb = text_box.T(text=name, loc=(x, y-12), line_style=None,
