@@ -1,5 +1,5 @@
 from pychart import *
-import Docsupport
+import pychart.doc_support
 import chartdemo
 import re
 
@@ -8,11 +8,12 @@ y = 500
 
 def drawLine(style):
     global x, y
-    name = Docsupport.stringify_value(style)
+    name = pychart.doc_support.stringify_value(style)
     name = re.sub("line_style\\.", "", name)
     name = re.sub("(\\d)(.)", "\\1-\n\\2", name) # create multi-line texts
     name = re.sub("black(.)", "black-\n\\1", name) # create multi-line texts
     canvas.line(style, x, y, x+20, y)
+    #print "name=", name
     tb = text_box.T(text=name, loc=(x, y-22), line_style=None)
     x = x + 60
     tb.draw()
