@@ -1,13 +1,15 @@
 from pychart import *
 
+theme.getopt()
+
 data = chart_data.read_csv("lines.csv")
 
 xaxis=axis.X(label="X", tic_interval=10)
 yaxis=axis.Y(label="Y", tic_interval=10)
 ar = area.T(x_range=(0,100), y_range=(0,100), x_axis=xaxis, y_axis=yaxis)
-eb = error_bar.error_bar2(tic_len=5, hline_style=line_style.gray5)
-ar.add_plot(line_plot.T(label="foo", data=data, error_bar=eb, y_min_col=3),
-            line_plot.T(label="bar", data=data, ycol=2, error_bar=eb, y_min_col=3))
+eb = error_bar.error_bar2(tic_len=5, hline_style=line_style.gray50)
+ar.add_plot(line_plot.T(label="foo", data=data, error_bar=eb, y_error_minus_col=3),
+            line_plot.T(label="bar", data=data, ycol=2, error_bar=eb, y_error_minus_col=3))
 ar.draw()
 
 tb = text_box.T(loc=(40, 130), text="This is\nimportant!", line_style=None)
