@@ -2,11 +2,11 @@ from pychart import *
 import tocslib
 data = [[128, 637], [256, 651], [512, 680], [1024, 737], [2048, 851]]
 
-ar = area.T(x_axis = axis.X(label="Hash map size", first_tic_value=128,
-                            tic_interval=2),
+ar = area.T(x_axis = axis.X(label="Hash map size", 
+                            tic_interval=lambda x,y: [128,256,512,1024,2048]),
             y_axis = axis.Y(label="Recovery cost(ms)",
-                            tic_interval = lambda x,y: (0,600,700,800,900,1000)),
-            x_log_base=2,
+                            tic_interval=lambda x,y: (600,700,800,900,1000)),
+            x_grid_interval = 2,
             y_range = (0, 1000),
             x_range = (100, 2400),
             x_coord_system = "log")
