@@ -1,5 +1,5 @@
 from pychart import *
-import Docsupport
+import pychart.doc_support
 import chartdemo
 import re
 
@@ -8,7 +8,7 @@ y = 100
 
 def draw_tick(tick):
     global x, y
-    name = Docsupport.stringify_value(tick)
+    name = pychart.doc_support.stringify_value(tick)
     name = re.sub("tick_mark\\.", "", name)
     tick.draw(x, y+tick.size/2)
     tb = text_box.T(text="/12" + name, loc=(x, y-20), line_style=None)
